@@ -2,6 +2,8 @@ import os
 from typing import Optional
 
 from pycarlo.core import Client, Mutation, Query
+import click
+from tabulate import tabulate
 
 from montecarlodata.config import Config
 from montecarlodata.errors import manage_errors
@@ -74,6 +76,7 @@ class DatabricksOnboardingService(BaseOnboardingService):
                 databricks_job_name=databricks_job_config.workspace_job_name,
                 databricks_notebook_path=databricks_job_config.workspace_notebook_path,
                 databricks_notebook_source=databricks_job_config.notebook_source,
+                databricks_notebook_version=databricks_job_config.notebook_version
             )
         else:
             job_info = dict(
@@ -115,3 +118,34 @@ class DatabricksOnboardingService(BaseOnboardingService):
                      connection_type=connection_type,
                      job_limits=job_limits,
                      **kwargs)
+
+
+    @manage_errors
+    def update_databricks_notebook(self, **kwargs):
+        mutation = Mutation()
+        mutation.update_databricks_notebook(**kwargs)
+        resp = self._mc_client(mutation)
+        click.echo(resp.update_databricks_notebook)
+
+    @manage_errors
+    def get_databricks_job_info(self, **kwargs):
+        query = Query()
+        query.get_databricks_metadata_job_info(**kwargs)
+        resp = self._mc_client(query)
+        attributes = [
+            'workspace_job_id',
+            'workspace_job_name',
+            'workspace_notebook_path',
+            'notebook_source',
+            'notebook_version'
+        ]
+        info_list = [{attribute: getattr(info, attribute) for attribute in attributes} for info in resp.get_databricks_metadata_job_info]
+        click.echo(tabulate(info_list, headers='keys'))
+
+
+    @manage_errors
+    def get_current_databricks_notebook_version(self):
+        query = Query()
+        query.get_current_databricks_notebook_version()
+        resp = self._mc_client(query)
+        click.echo(resp.get_current_databricks_notebook_version)
