@@ -12,7 +12,12 @@ EXPECTED_DATABRICKS_GQL_RESPONSE_FIELD = 'testDatabricksCredentials'
 EXPECTED_SNOWFLAKE_GQL_RESPONSE_FIELD = 'testSnowflakeCredentials'
 EXPECTED_BQ_GQL_RESPONSE_FIELD = 'testBqCredentials'
 EXPECTED_SELF_HOSTED_GQL_RESPONSE_FIELD = 'testSelfHostedCredentials'
-EXPECTED_TOGGLE_EVENTS_GQL_RESPONSE_FIELD = 'toggleEventConfig'
+EXPECTED_CONFIGURE_AIRFLOW_LOG_EVENTS_GQL_RESPONSE_FIELD = 'configureAirflowLogEvents'
+EXPECTED_CONFIGURE_METADATA_EVENTS_GQL_RESPONSE_FIELD = 'configureMetadataEvents'
+EXPECTED_CONFIGURE_QUERY_LOG_EVENTS_GQL_RESPONSE_FIELD = 'configureQueryLogEvents'
+EXPECTED_DISABLE_AIRFLOW_LOG_EVENTS_GQL_RESPONSE_FIELD = 'disableAirflowLogEvents'
+EXPECTED_DISABLE_METADATA_EVENTS_GQL_RESPONSE_FIELD = 'disableMetadataEvents'
+EXPECTED_DISABLE_QUERY_LOG_EVENTS_GQL_RESPONSE_FIELD = 'disableQueryLogEvents'
 EXPECTED_UPDATE_CREDENTIALS_RESPONSE_FIELD = 'updateCredentials'
 EXPECTED_REMOVE_CONNECTION_RESPONSE_FIELD = 'removeConnection'
 EXPECTED_TEST_EXISTING_RESPONSE_FIELD = 'testExistingConnection'
