@@ -1,22 +1,23 @@
 # Queries related to managing the collector
 
 GENERATE_COLLECTOR_TEMPLATE = """
-mutation generateCollectorTemplate($region:String, $dcId:UUID) {
-  generateCollectorTemplate(region:$region, dcId:$dcId) {
+mutation generateCollectorTemplate($region:String, $dcId:UUID, $updateInfra:Boolean) {
+  generateCollectorTemplate(region:$region, dcId:$dcId, updateInfra: $updateInfra) {
     dc {
       templateLaunchUrl
       stackArn
       customerAwsAccountId
       active
       apiGatewayId
+      templateVariant
     }
   }
 }
 """
 
 ADD_COLLECTOR_RECORD = """
-mutation createCollectorRecord($templateProvider:String, $templateVariant:String) {
-  createCollectorRecord(templateProvider:$templateProvider, templateVariant:$templateVariant) {
+mutation createCollectorRecord {
+  createCollectorRecord {
     dc {
       uuid
     }
